@@ -8,15 +8,15 @@ namespace Genfun {
   
   FUNCTION_OBJECT_IMP(EnergyFunction)
 
-  EnergyFunction::EnergyFunction(const Classical::Solver & solver):
-  solver(solver)
+  EnergyFunction::EnergyFunction(const Classical::Solver & xsolver):
+  solver(xsolver)
   {}
   
   EnergyFunction::~EnergyFunction() {
   }
   
   EnergyFunction::EnergyFunction(const EnergyFunction & right) 
-    :solver(right.solver)
+    :AbsFunction(right), solver(right.solver)
   {  }
   
   
