@@ -14,8 +14,8 @@ FUNCTION_OBJECT_IMP(CumulativeChiSquare)
 // terms of the incomplete gamma function.                                         //
 //---------------------------------------------------------------------------------//
 
-CumulativeChiSquare::CumulativeChiSquare(unsigned int nDof):
-  _nDof(nDof)
+CumulativeChiSquare::CumulativeChiSquare(unsigned int ndf):
+  _nDof(ndf)
 {
   create();
 }
@@ -25,6 +25,7 @@ CumulativeChiSquare::~CumulativeChiSquare() {
 }
 
 CumulativeChiSquare::CumulativeChiSquare(const CumulativeChiSquare & right):
+AbsFunction(right),
 _nDof(right._nDof)
 {
   create();
