@@ -16,6 +16,7 @@ GammaDistribution::GammaDistribution():
 {}
 
 GammaDistribution::GammaDistribution(const GammaDistribution & right):
+AbsFunction(right),
 _alpha(right._alpha),
 _beta (right._beta) 
 {
@@ -25,8 +26,8 @@ GammaDistribution::~GammaDistribution() {
 }
 
 double GammaDistribution::operator() (double x) const {
-  return pow(x,_alpha.getValue()-1)*
-    exp(-x/_beta.getValue())/pow(_beta.getValue(),(_alpha.getValue()))/
+  return std::pow(x,_alpha.getValue()-1)*
+    exp(-x/_beta.getValue())/std::pow(_beta.getValue(),(_alpha.getValue()))/
     exp(_logGamma(_alpha.getValue()));
 
 }
