@@ -14,7 +14,7 @@
 //
 // =======================================================================
 // Ken Smith      - Initial draft: 14th Jul 1998
-//                - Removed pow() from flat method 14th Jul 1998
+//                - Removed std::pow() from flat method 14th Jul 1998
 //                - Added conversion operators:  6th Aug 1998
 //
 // Mark Fischler  The following were modified mostly to make the routine
@@ -59,11 +59,9 @@
 #include "CLHEP/Random/engineIDulong.h"
 #include "CLHEP/Random/DoubConv.hh"
 #include <string.h>	// for strcmp
-#include <cstdlib>	// for abs(int)
+#include <cstdlib>	// for std::abs(int)
 #include <limits>	// for numeric_limits
 
-using namespace std;
-
 namespace CLHEP {
 
 static const int MarkerLen = 64; // Enough room to hold a begin or end marker. 
@@ -105,8 +103,8 @@ Ranlux64Engine::Ranlux64Engine()
 : HepRandomEngine()
 {
    luxury = 1;
-   int cycle    = abs(int(numEngines/maxIndex));
-   int curIndex = abs(int(numEngines%maxIndex));
+   int cycle    = std::abs(int(numEngines/maxIndex));
+   int curIndex = std::abs(int(numEngines%maxIndex));
    numEngines +=1;
    long mask = ((cycle & 0x007fffff) << 8);
    long seedlist[2];
@@ -130,12 +128,12 @@ Ranlux64Engine::Ranlux64Engine(long seed, int lux)
 				// point in the sequence.  
 }
 
-Ranlux64Engine::Ranlux64Engine(int rowIndex, int colIndex, int lux)
+Ranlux64Engine::Ranlux64Engine(int rowIndex, int, int lux)
 : HepRandomEngine()
 {
    luxury = lux;
-   int cycle = abs(int(rowIndex/maxIndex));
-   int   row = abs(int(rowIndex%maxIndex));
+   int cycle = std::abs(int(rowIndex/maxIndex));
+   int   row = std::abs(int(rowIndex%maxIndex));
    long mask = (( cycle & 0x000007ff ) << 20 );
    long seedlist[2]; 
    HepRandom::getTheTableSeeds( seedlist, row );
