@@ -30,18 +30,18 @@ static inline double safe_acos (double x) {
 }
 
 HepRotationX::HepRotationX(double ddelta) : 
-		d(proper(ddelta)), s(std::sin(ddelta)), c(std::cos(ddelta))
+		its_d(proper(ddelta)), its_s(std::sin(ddelta)), its_c(std::cos(ddelta))
 {}
 
 HepRotationX & HepRotationX::set ( double ddelta ) {
-  d = proper(ddelta);
-  s = std::sin(d);
-  c = std::cos(d);
+  its_d = proper(ddelta);
+  its_s = std::sin(its_d);
+  its_c = std::cos(its_d);
   return *this;
 }
 
 double  HepRotationX::phi() const {
-  if ( (d > 0) && (d < CLHEP::pi) ) {
+  if ( (its_d > 0) && (its_d < CLHEP::pi) ) {
     return CLHEP::pi;
   } else {
     return 0.0;
@@ -49,11 +49,11 @@ double  HepRotationX::phi() const {
 }  // HepRotationX::phi()
 
 double  HepRotationX::theta() const {
-  return  std::fabs( d );
+  return  std::fabs( its_d );
 }  // HepRotationX::theta()
 
 double  HepRotationX::psi() const {
-  if ( (d > 0) && (d < CLHEP::pi) ) {
+  if ( (its_d > 0) && (its_d < CLHEP::pi) ) {
     return CLHEP::pi;
   } else {
     return 0.0;
@@ -130,7 +130,7 @@ void HepRotationX::decompose
 }
 
 double HepRotationX::distance2( const HepRotationX & r  ) const {
-  double answer = 2.0 * ( 1.0 - ( s * r.s + c * r.c ) ) ;
+  double answer = 2.0 * ( 1.0 - ( its_s * r.its_s + its_c * r.its_c ) ) ;
   return (answer >= 0) ? answer : 0;
 }
 
@@ -184,12 +184,12 @@ bool HepRotationX::isNear( const HepLorentzRotation & lt,
 }
 
 double HepRotationX::norm2() const {
-  return 2.0 - 2.0 * c;
+  return 2.0 - 2.0 * its_c;
 }
 
 std::ostream & HepRotationX::print( std::ostream & os ) const {
-  os << "\nRotation about X (" << d << 
-		") [cos d = " << c << " sin d = " << s << "]\n";
+  os << "\nRotation about X (" << its_d << 
+		") [cos d = " << its_c << " sin d = " << its_s << "]\n";
   return os;
 }
 
